@@ -31,17 +31,11 @@ class DescribeDiagnosticReportListRequest(RpcRequest):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
 
-	def get_skipAuth(self):
-		return self.get_query_params().get('skipAuth')
+	def get_EndTime(self):
+		return self.get_query_params().get('EndTime')
 
-	def set_skipAuth(self,skipAuth):
-		self.add_query_param('skipAuth',skipAuth)
-
-	def get_signature(self):
-		return self.get_query_params().get('signature')
-
-	def set_signature(self,signature):
-		self.add_query_param('signature',signature)
+	def set_EndTime(self,EndTime):
+		self.add_query_param('EndTime',EndTime)
 
 	def get_StartTime(self):
 		return self.get_query_params().get('StartTime')
@@ -49,23 +43,11 @@ class DescribeDiagnosticReportListRequest(RpcRequest):
 	def set_StartTime(self,StartTime):
 		self.add_query_param('StartTime',StartTime)
 
-	def get_UserId(self):
-		return self.get_query_params().get('UserId')
+	def get_PageNo(self):
+		return self.get_query_params().get('PageNo')
 
-	def set_UserId(self,UserId):
-		self.add_query_param('UserId',UserId)
-
-	def get_Uid(self):
-		return self.get_query_params().get('Uid')
-
-	def set_Uid(self,Uid):
-		self.add_query_param('Uid',Uid)
-
-	def get_accessKey(self):
-		return self.get_query_params().get('accessKey')
-
-	def set_accessKey(self,accessKey):
-		self.add_query_param('accessKey',accessKey)
+	def set_PageNo(self,PageNo):
+		self.add_query_param('PageNo',PageNo)
 
 	def get_PageSize(self):
 		return self.get_query_params().get('PageSize')
@@ -77,28 +59,4 @@ class DescribeDiagnosticReportListRequest(RpcRequest):
 		return self.get_query_params().get('DBInstanceId')
 
 	def set_DBInstanceId(self,DBInstanceId):
-		self.add_query_param('DBInstanceId',DBInstanceId)
-
-	def get_timestamp(self):
-		return self.get_query_params().get('timestamp')
-
-	def set_timestamp(self,timestamp):
-		self.add_query_param('timestamp',timestamp)
-
-	def get___context(self):
-		return self.get_query_params().get('__context')
-
-	def set___context(self,__context):
-		self.add_query_param('__context',__context)
-
-	def get_EndTime(self):
-		return self.get_query_params().get('EndTime')
-
-	def set_EndTime(self,EndTime):
-		self.add_query_param('EndTime',EndTime)
-
-	def get_PageNo(self):
-		return self.get_query_params().get('PageNo')
-
-	def set_PageNo(self,PageNo):
-		self.add_query_param('PageNo',PageNo)
\ No newline at end of file
+		self.add_query_param('DBInstanceId',DBInstanceId)
\ No newline at end of file
